## Installation

```bash
pip install mydream
```

## RUN
```bash
mydream start --config dream.ini --no-download
mydream stop
```

## REQUIREMENT
```bash
numpy
lightgbm
uwsgi
flask
python-magic-bin==0.4.14
click
```